@@ -2,6 +2,7 @@
 """aiohttp requester module."""
 
 import asyncio
+import contextlib
 import logging
 from asyncio.events import AbstractEventLoop, AbstractServer
 from socket import AddressFamily  # pylint: disable=no-name-in-module
@@ -80,9 +81,9 @@ class AiohttpRequester(UpnpRequester):
 
                         resp_body_text = await response.text()
         except asyncio.TimeoutError as err:
-            raise UpnpConnectionTimeoutError from err
+            raise UpnpConnectionTimeoutError(str(err)) from err
         except aiohttp.ClientConnectionError as err:
-            raise UpnpConnectionError from err
+            raise UpnpConnectionError(str(err)) from err
         except aiohttp.ClientResponseError as err:
             raise UpnpClientResponseError(
                 request_info=err.request_info,
@@ -92,9 +93,9 @@ class AiohttpRequester(UpnpRequester):
                 headers=err.headers,
             ) from err
         except aiohttp.ClientError as err:
-            raise UpnpCommunicationError from err
+            raise UpnpCommunicationError(str(err)) from err
         except UnicodeDecodeError as err:
-            raise UpnpCommunicationError from err
+            raise UpnpCommunicationError(str(err)) from err
 
         return status, resp_headers, resp_body_text
 
@@ -127,6 +128,26 @@ class AiohttpSessionRequester(UpnpRequester):
         url: str,
         headers: Optional[Mapping[str, str]] = None,
         body: Optional[str] = None,
+    ) -> Tuple[int, Mapping[str, str], str]:
+        """Do a HTTP request with a retry on ServerDisconnectedError.
+
+        The HTTP/1.1 spec allows the server to disconnect at any time.
+        We want to retry the request in this event.
+        """
+        for _ in range(2):
+            with contextlib.suppress(aiohttp.ServerDisconnectedError):
+                return await self._async_http_request(method, url, headers, body)
+        try:
+            return await self._async_http_request(method, url, headers, body)
+        except aiohttp.ServerDisconnectedError as err:
+            raise UpnpConnectionError(str(err)) from err
+
+    async def _async_http_request(
+        self,
+        method: str,
+        url: str,
+        headers: Optional[Mapping[str, str]] = None,
+        body: Optional[str] = None,
     ) -> Tuple[int, Mapping[str, str], str]:
         """Do a HTTP request."""
         # pylint: disable=too-many-arguments
@@ -165,9 +186,11 @@ class AiohttpSessionRequester(UpnpRequester):
 
                     resp_body_text = await response.text()
         except asyncio.TimeoutError as err:
-            raise UpnpConnectionTimeoutError from err
+            raise UpnpConnectionTimeoutError(str(err)) from err
+        except aiohttp.ServerDisconnectedError:
+            raise
         except aiohttp.ClientConnectionError as err:
-            raise UpnpConnectionError from err
+            raise UpnpConnectionError(str(err)) from err
         except aiohttp.ClientResponseError as err:
             raise UpnpClientResponseError(
                 request_info=err.request_info,
@@ -177,9 +200,9 @@ class AiohttpSessionRequester(UpnpRequester):
                 headers=err.headers,
             ) from err
         except aiohttp.ClientError as err:
-            raise UpnpCommunicationError from err
+            raise UpnpCommunicationError(str(err)) from err
         except UnicodeDecodeError as err:
-            raise UpnpCommunicationError from err
+            raise UpnpCommunicationError(str(err)) from err
 
         return status, resp_headers, resp_body_text
 
